#!/usr/bin/python -tt
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
# SPDX-License-Identifier: GPL-3.0-or-later
# SPDX-FileCopyrightText: Ansible Project, 2020

import os
import sys
from setuptools import setup, find_namespace_packages

__version__ = '8.0.0a1'
__author__ = 'Ansible, Inc.'


with open('README.rst', 'r') as f:
    long_desc = f.read()

setup(
    name='ansible',
    version=__version__,
    description='Radically simple IT automation',
    long_description=long_desc,
    author=__author__,
    author_email='info@ansible.com',
    url='https://ansible.com/',
    project_urls={
        'Bug Tracker': 'https://github.com/ansible/ansible/issues',
        'Code of Conduct': 'https://docs.ansible.com/ansible/latest/community/code_of_conduct.html',
        'Documentation': 'https://docs.ansible.com/ansible/',
        'Mailing lists': 'https://docs.ansible.com/ansible/latest/community/communication.html#mailing-list-information',
        'Source Code': 'https://github.com/ansible/ansible',
    },
    license='GPLv3+',
    python_requires='>=3.9',
    packages=find_namespace_packages(
        '.',
        include=[
            'ansible_collections',
            'ansible_collections.*',
        ],
        exclude=[
            'ansible_collections.amazon.aws.tests.*',
            'ansible_collections.amazon.aws.tests',
            'ansible_collections.amazon.aws.docs.*',
            'ansible_collections.amazon.aws.docs',
            'ansible_collections.ansible.netcommon.tests.*',
            'ansible_collections.ansible.netcommon.tests',
            'ansible_collections.ansible.netcommon.docs.*',
            'ansible_collections.ansible.netcommon.docs',
            'ansible_collections.ansible.posix.tests.*',
            'ansible_collections.ansible.posix.tests',
            'ansible_collections.ansible.posix.docs.*',
            'ansible_collections.ansible.posix.docs',
            'ansible_collections.ansible.utils.tests.*',
            'ansible_collections.ansible.utils.tests',
            'ansible_collections.ansible.utils.docs.*',
            'ansible_collections.ansible.utils.docs',
            'ansible_collections.ansible.windows.tests.*',
            'ansible_collections.ansible.windows.tests',
            'ansible_collections.ansible.windows.docs.*',
            'ansible_collections.ansible.windows.docs',
            'ansible_collections.arista.eos.tests.*',
            'ansible_collections.arista.eos.tests',
            'ansible_collections.arista.eos.docs.*',
            'ansible_collections.arista.eos.docs',
            'ansible_collections.awx.awx.tests.*',
            'ansible_collections.awx.awx.tests',
            'ansible_collections.awx.awx.docs.*',
            'ansible_collections.awx.awx.docs',
            'ansible_collections.azure.azcollection.tests.*',
            'ansible_collections.azure.azcollection.tests',
            'ansible_collections.azure.azcollection.docs.*',
            'ansible_collections.azure.azcollection.docs',
            'ansible_collections.check_point.mgmt.tests.*',
            'ansible_collections.check_point.mgmt.tests',
            'ansible_collections.check_point.mgmt.docs.*',
            'ansible_collections.check_point.mgmt.docs',
            'ansible_collections.chocolatey.chocolatey.tests.*',
            'ansible_collections.chocolatey.chocolatey.tests',
            'ansible_collections.chocolatey.chocolatey.docs.*',
            'ansible_collections.chocolatey.chocolatey.docs',
            'ansible_collections.cisco.aci.tests.*',
            'ansible_collections.cisco.aci.tests',
            'ansible_collections.cisco.aci.docs.*',
            'ansible_collections.cisco.aci.docs',
            'ansible_collections.cisco.asa.tests.*',
            'ansible_collections.cisco.asa.tests',
            'ansible_collections.cisco.asa.docs.*',
            'ansible_collections.cisco.asa.docs',
            'ansible_collections.cisco.dnac.tests.*',
            'ansible_collections.cisco.dnac.tests',
            'ansible_collections.cisco.dnac.docs.*',
            'ansible_collections.cisco.dnac.docs',
            'ansible_collections.cisco.intersight.tests.*',
            'ansible_collections.cisco.intersight.tests',
            'ansible_collections.cisco.intersight.docs.*',
            'ansible_collections.cisco.intersight.docs',
            'ansible_collections.cisco.ios.tests.*',
            'ansible_collections.cisco.ios.tests',
            'ansible_collections.cisco.ios.docs.*',
            'ansible_collections.cisco.ios.docs',
            'ansible_collections.cisco.iosxr.tests.*',
            'ansible_collections.cisco.iosxr.tests',
            'ansible_collections.cisco.iosxr.docs.*',
            'ansible_collections.cisco.iosxr.docs',
            'ansible_collections.cisco.ise.tests.*',
            'ansible_collections.cisco.ise.tests',
            'ansible_collections.cisco.ise.docs.*',
            'ansible_collections.cisco.ise.docs',
            'ansible_collections.cisco.meraki.tests.*',
            'ansible_collections.cisco.meraki.tests',
            'ansible_collections.cisco.meraki.docs.*',
            'ansible_collections.cisco.meraki.docs',
            'ansible_collections.cisco.mso.tests.*',
            'ansible_collections.cisco.mso.tests',
            'ansible_collections.cisco.mso.docs.*',
            'ansible_collections.cisco.mso.docs',
            'ansible_collections.cisco.nso.tests.*',
            'ansible_collections.cisco.nso.tests',
            'ansible_collections.cisco.nso.docs.*',
            'ansible_collections.cisco.nso.docs',
            'ansible_collections.cisco.nxos.tests.*',
            'ansible_collections.cisco.nxos.tests',
            'ansible_collections.cisco.nxos.docs.*',
            'ansible_collections.cisco.nxos.docs',
            'ansible_collections.cisco.ucs.tests.*',
            'ansible_collections.cisco.ucs.tests',
            'ansible_collections.cisco.ucs.docs.*',
            'ansible_collections.cisco.ucs.docs',
            'ansible_collections.cloud.common.tests.*',
            'ansible_collections.cloud.common.tests',
            'ansible_collections.cloud.common.docs.*',
            'ansible_collections.cloud.common.docs',
            'ansible_collections.cloudscale_ch.cloud.tests.*',
            'ansible_collections.cloudscale_ch.cloud.tests',
            'ansible_collections.cloudscale_ch.cloud.docs.*',
            'ansible_collections.cloudscale_ch.cloud.docs',
            'ansible_collections.community.aws.tests.*',
            'ansible_collections.community.aws.tests',
            'ansible_collections.community.aws.docs.*',
            'ansible_collections.community.aws.docs',
            'ansible_collections.community.azure.tests.*',
            'ansible_collections.community.azure.tests',
            'ansible_collections.community.azure.docs.*',
            'ansible_collections.community.azure.docs',
            'ansible_collections.community.ciscosmb.tests.*',
            'ansible_collections.community.ciscosmb.tests',
            'ansible_collections.community.ciscosmb.docs.*',
            'ansible_collections.community.ciscosmb.docs',
            'ansible_collections.community.crypto.tests.*',
            'ansible_collections.community.crypto.tests',
            'ansible_collections.community.crypto.docs.*',
            'ansible_collections.community.crypto.docs',
            'ansible_collections.community.digitalocean.tests.*',
            'ansible_collections.community.digitalocean.tests',
            'ansible_collections.community.digitalocean.docs.*',
            'ansible_collections.community.digitalocean.docs',
            'ansible_collections.community.dns.tests.*',
            'ansible_collections.community.dns.tests',
            'ansible_collections.community.dns.docs.*',
            'ansible_collections.community.dns.docs',
            'ansible_collections.community.docker.tests.*',
            'ansible_collections.community.docker.tests',
            'ansible_collections.community.docker.docs.*',
            'ansible_collections.community.docker.docs',
            'ansible_collections.community.fortios.tests.*',
            'ansible_collections.community.fortios.tests',
            'ansible_collections.community.fortios.docs.*',
            'ansible_collections.community.fortios.docs',
            'ansible_collections.community.general.tests.*',
            'ansible_collections.community.general.tests',
            'ansible_collections.community.general.docs.*',
            'ansible_collections.community.general.docs',
            'ansible_collections.community.google.tests.*',
            'ansible_collections.community.google.tests',
            'ansible_collections.community.google.docs.*',
            'ansible_collections.community.google.docs',
            'ansible_collections.community.grafana.tests.*',
            'ansible_collections.community.grafana.tests',
            'ansible_collections.community.grafana.docs.*',
            'ansible_collections.community.grafana.docs',
            'ansible_collections.community.hashi_vault.tests.*',
            'ansible_collections.community.hashi_vault.tests',
            'ansible_collections.community.hashi_vault.docs.*',
            'ansible_collections.community.hashi_vault.docs',
            'ansible_collections.community.hrobot.tests.*',
            'ansible_collections.community.hrobot.tests',
            'ansible_collections.community.hrobot.docs.*',
            'ansible_collections.community.hrobot.docs',
            'ansible_collections.community.libvirt.tests.*',
            'ansible_collections.community.libvirt.tests',
            'ansible_collections.community.libvirt.docs.*',
            'ansible_collections.community.libvirt.docs',
            'ansible_collections.community.mongodb.tests.*',
            'ansible_collections.community.mongodb.tests',
            'ansible_collections.community.mongodb.docs.*',
            'ansible_collections.community.mongodb.docs',
            'ansible_collections.community.mysql.tests.*',
            'ansible_collections.community.mysql.tests',
            'ansible_collections.community.mysql.docs.*',
            'ansible_collections.community.mysql.docs',
            'ansible_collections.community.network.tests.*',
            'ansible_collections.community.network.tests',
            'ansible_collections.community.network.docs.*',
            'ansible_collections.community.network.docs',
            'ansible_collections.community.okd.tests.*',
            'ansible_collections.community.okd.tests',
            'ansible_collections.community.okd.docs.*',
            'ansible_collections.community.okd.docs',
            'ansible_collections.community.postgresql.tests.*',
            'ansible_collections.community.postgresql.tests',
            'ansible_collections.community.postgresql.docs.*',
            'ansible_collections.community.postgresql.docs',
            'ansible_collections.community.proxysql.tests.*',
            'ansible_collections.community.proxysql.tests',
            'ansible_collections.community.proxysql.docs.*',
            'ansible_collections.community.proxysql.docs',
            'ansible_collections.community.rabbitmq.tests.*',
            'ansible_collections.community.rabbitmq.tests',
            'ansible_collections.community.rabbitmq.docs.*',
            'ansible_collections.community.rabbitmq.docs',
            'ansible_collections.community.routeros.tests.*',
            'ansible_collections.community.routeros.tests',
            'ansible_collections.community.routeros.docs.*',
            'ansible_collections.community.routeros.docs',
            'ansible_collections.community.sap.tests.*',
            'ansible_collections.community.sap.tests',
            'ansible_collections.community.sap.docs.*',
            'ansible_collections.community.sap.docs',
            'ansible_collections.community.sap_libs.tests.*',
            'ansible_collections.community.sap_libs.tests',
            'ansible_collections.community.sap_libs.docs.*',
            'ansible_collections.community.sap_libs.docs',
            'ansible_collections.community.skydive.tests.*',
            'ansible_collections.community.skydive.tests',
            'ansible_collections.community.skydive.docs.*',
            'ansible_collections.community.skydive.docs',
            'ansible_collections.community.sops.tests.*',
            'ansible_collections.community.sops.tests',
            'ansible_collections.community.sops.docs.*',
            'ansible_collections.community.sops.docs',
            'ansible_collections.community.vmware.tests.*',
            'ansible_collections.community.vmware.tests',
            'ansible_collections.community.vmware.docs.*',
            'ansible_collections.community.vmware.docs',
            'ansible_collections.community.windows.tests.*',
            'ansible_collections.community.windows.tests',
            'ansible_collections.community.windows.docs.*',
            'ansible_collections.community.windows.docs',
            'ansible_collections.community.zabbix.tests.*',
            'ansible_collections.community.zabbix.tests',
            'ansible_collections.community.zabbix.docs.*',
            'ansible_collections.community.zabbix.docs',
            'ansible_collections.containers.podman.tests.*',
            'ansible_collections.containers.podman.tests',
            'ansible_collections.containers.podman.docs.*',
            'ansible_collections.containers.podman.docs',
            'ansible_collections.cyberark.conjur.tests.*',
            'ansible_collections.cyberark.conjur.tests',
            'ansible_collections.cyberark.conjur.docs.*',
            'ansible_collections.cyberark.conjur.docs',
            'ansible_collections.cyberark.pas.tests.*',
            'ansible_collections.cyberark.pas.tests',
            'ansible_collections.cyberark.pas.docs.*',
            'ansible_collections.cyberark.pas.docs',
            'ansible_collections.dellemc.enterprise_sonic.tests.*',
            'ansible_collections.dellemc.enterprise_sonic.tests',
            'ansible_collections.dellemc.enterprise_sonic.docs.*',
            'ansible_collections.dellemc.enterprise_sonic.docs',
            'ansible_collections.dellemc.openmanage.tests.*',
            'ansible_collections.dellemc.openmanage.tests',
            'ansible_collections.dellemc.openmanage.docs.*',
            'ansible_collections.dellemc.openmanage.docs',
            'ansible_collections.dellemc.powerflex.tests.*',
            'ansible_collections.dellemc.powerflex.tests',
            'ansible_collections.dellemc.powerflex.docs.*',
            'ansible_collections.dellemc.powerflex.docs',
            'ansible_collections.dellemc.unity.tests.*',
            'ansible_collections.dellemc.unity.tests',
            'ansible_collections.dellemc.unity.docs.*',
            'ansible_collections.dellemc.unity.docs',
            'ansible_collections.f5networks.f5_modules.tests.*',
            'ansible_collections.f5networks.f5_modules.tests',
            'ansible_collections.f5networks.f5_modules.docs.*',
            'ansible_collections.f5networks.f5_modules.docs',
            'ansible_collections.fortinet.fortimanager.tests.*',
            'ansible_collections.fortinet.fortimanager.tests',
            'ansible_collections.fortinet.fortimanager.docs.*',
            'ansible_collections.fortinet.fortimanager.docs',
            'ansible_collections.fortinet.fortios.tests.*',
            'ansible_collections.fortinet.fortios.tests',
            'ansible_collections.fortinet.fortios.docs.*',
            'ansible_collections.fortinet.fortios.docs',
            'ansible_collections.frr.frr.tests.*',
            'ansible_collections.frr.frr.tests',
            'ansible_collections.frr.frr.docs.*',
            'ansible_collections.frr.frr.docs',
            'ansible_collections.gluster.gluster.tests.*',
            'ansible_collections.gluster.gluster.tests',
            'ansible_collections.gluster.gluster.docs.*',
            'ansible_collections.gluster.gluster.docs',
            'ansible_collections.google.cloud.tests.*',
            'ansible_collections.google.cloud.tests',
            'ansible_collections.google.cloud.docs.*',
            'ansible_collections.google.cloud.docs',
            'ansible_collections.grafana.grafana.tests.*',
            'ansible_collections.grafana.grafana.tests',
            'ansible_collections.grafana.grafana.docs.*',
            'ansible_collections.grafana.grafana.docs',
            'ansible_collections.hetzner.hcloud.tests.*',
            'ansible_collections.hetzner.hcloud.tests',
            'ansible_collections.hetzner.hcloud.docs.*',
            'ansible_collections.hetzner.hcloud.docs',
            'ansible_collections.hpe.nimble.tests.*',
            'ansible_collections.hpe.nimble.tests',
            'ansible_collections.hpe.nimble.docs.*',
            'ansible_collections.hpe.nimble.docs',
            'ansible_collections.ibm.qradar.tests.*',
            'ansible_collections.ibm.qradar.tests',
            'ansible_collections.ibm.qradar.docs.*',
            'ansible_collections.ibm.qradar.docs',
            'ansible_collections.ibm.spectrum_virtualize.tests.*',
            'ansible_collections.ibm.spectrum_virtualize.tests',
            'ansible_collections.ibm.spectrum_virtualize.docs.*',
            'ansible_collections.ibm.spectrum_virtualize.docs',
            'ansible_collections.infinidat.infinibox.tests.*',
            'ansible_collections.infinidat.infinibox.tests',
            'ansible_collections.infinidat.infinibox.docs.*',
            'ansible_collections.infinidat.infinibox.docs',
            'ansible_collections.infoblox.nios_modules.tests.*',
            'ansible_collections.infoblox.nios_modules.tests',
            'ansible_collections.infoblox.nios_modules.docs.*',
            'ansible_collections.infoblox.nios_modules.docs',
            'ansible_collections.inspur.ispim.tests.*',
            'ansible_collections.inspur.ispim.tests',
            'ansible_collections.inspur.ispim.docs.*',
            'ansible_collections.inspur.ispim.docs',
            'ansible_collections.inspur.sm.tests.*',
            'ansible_collections.inspur.sm.tests',
            'ansible_collections.inspur.sm.docs.*',
            'ansible_collections.inspur.sm.docs',
            'ansible_collections.junipernetworks.junos.tests.*',
            'ansible_collections.junipernetworks.junos.tests',
            'ansible_collections.junipernetworks.junos.docs.*',
            'ansible_collections.junipernetworks.junos.docs',
            'ansible_collections.kubernetes.core.tests.*',
            'ansible_collections.kubernetes.core.tests',
            'ansible_collections.kubernetes.core.docs.*',
            'ansible_collections.kubernetes.core.docs',
            'ansible_collections.lowlydba.sqlserver.tests.*',
            'ansible_collections.lowlydba.sqlserver.tests',
            'ansible_collections.lowlydba.sqlserver.docs.*',
            'ansible_collections.lowlydba.sqlserver.docs',
            'ansible_collections.microsoft.ad.tests.*',
            'ansible_collections.microsoft.ad.tests',
            'ansible_collections.microsoft.ad.docs.*',
            'ansible_collections.microsoft.ad.docs',
            'ansible_collections.netapp.aws.tests.*',
            'ansible_collections.netapp.aws.tests',
            'ansible_collections.netapp.aws.docs.*',
            'ansible_collections.netapp.aws.docs',
            'ansible_collections.netapp.azure.tests.*',
            'ansible_collections.netapp.azure.tests',
            'ansible_collections.netapp.azure.docs.*',
            'ansible_collections.netapp.azure.docs',
            'ansible_collections.netapp.cloudmanager.tests.*',
            'ansible_collections.netapp.cloudmanager.tests',
            'ansible_collections.netapp.cloudmanager.docs.*',
            'ansible_collections.netapp.cloudmanager.docs',
            'ansible_collections.netapp.elementsw.tests.*',
            'ansible_collections.netapp.elementsw.tests',
            'ansible_collections.netapp.elementsw.docs.*',
            'ansible_collections.netapp.elementsw.docs',
            'ansible_collections.netapp.ontap.tests.*',
            'ansible_collections.netapp.ontap.tests',
            'ansible_collections.netapp.ontap.docs.*',
            'ansible_collections.netapp.ontap.docs',
            'ansible_collections.netapp.storagegrid.tests.*',
            'ansible_collections.netapp.storagegrid.tests',
            'ansible_collections.netapp.storagegrid.docs.*',
            'ansible_collections.netapp.storagegrid.docs',
            'ansible_collections.netapp.um_info.tests.*',
            'ansible_collections.netapp.um_info.tests',
            'ansible_collections.netapp.um_info.docs.*',
            'ansible_collections.netapp.um_info.docs',
            'ansible_collections.netapp_eseries.santricity.tests.*',
            'ansible_collections.netapp_eseries.santricity.tests',
            'ansible_collections.netapp_eseries.santricity.docs.*',
            'ansible_collections.netapp_eseries.santricity.docs',
            'ansible_collections.netbox.netbox.tests.*',
            'ansible_collections.netbox.netbox.tests',
            'ansible_collections.netbox.netbox.docs.*',
            'ansible_collections.netbox.netbox.docs',
            'ansible_collections.ngine_io.cloudstack.tests.*',
            'ansible_collections.ngine_io.cloudstack.tests',
            'ansible_collections.ngine_io.cloudstack.docs.*',
            'ansible_collections.ngine_io.cloudstack.docs',
            'ansible_collections.ngine_io.exoscale.tests.*',
            'ansible_collections.ngine_io.exoscale.tests',
            'ansible_collections.ngine_io.exoscale.docs.*',
            'ansible_collections.ngine_io.exoscale.docs',
            'ansible_collections.ngine_io.vultr.tests.*',
            'ansible_collections.ngine_io.vultr.tests',
            'ansible_collections.ngine_io.vultr.docs.*',
            'ansible_collections.ngine_io.vultr.docs',
            'ansible_collections.openstack.cloud.tests.*',
            'ansible_collections.openstack.cloud.tests',
            'ansible_collections.openstack.cloud.docs.*',
            'ansible_collections.openstack.cloud.docs',
            'ansible_collections.openvswitch.openvswitch.tests.*',
            'ansible_collections.openvswitch.openvswitch.tests',
            'ansible_collections.openvswitch.openvswitch.docs.*',
            'ansible_collections.openvswitch.openvswitch.docs',
            'ansible_collections.ovirt.ovirt.tests.*',
            'ansible_collections.ovirt.ovirt.tests',
            'ansible_collections.ovirt.ovirt.docs.*',
            'ansible_collections.ovirt.ovirt.docs',
            'ansible_collections.purestorage.flasharray.tests.*',
            'ansible_collections.purestorage.flasharray.tests',
            'ansible_collections.purestorage.flasharray.docs.*',
            'ansible_collections.purestorage.flasharray.docs',
            'ansible_collections.purestorage.flashblade.tests.*',
            'ansible_collections.purestorage.flashblade.tests',
            'ansible_collections.purestorage.flashblade.docs.*',
            'ansible_collections.purestorage.flashblade.docs',
            'ansible_collections.purestorage.fusion.tests.*',
            'ansible_collections.purestorage.fusion.tests',
            'ansible_collections.purestorage.fusion.docs.*',
            'ansible_collections.purestorage.fusion.docs',
            'ansible_collections.sensu.sensu_go.tests.*',
            'ansible_collections.sensu.sensu_go.tests',
            'ansible_collections.sensu.sensu_go.docs.*',
            'ansible_collections.sensu.sensu_go.docs',
            'ansible_collections.servicenow.servicenow.tests.*',
            'ansible_collections.servicenow.servicenow.tests',
            'ansible_collections.servicenow.servicenow.docs.*',
            'ansible_collections.servicenow.servicenow.docs',
            'ansible_collections.splunk.es.tests.*',
            'ansible_collections.splunk.es.tests',
            'ansible_collections.splunk.es.docs.*',
            'ansible_collections.splunk.es.docs',
            'ansible_collections.t_systems_mms.icinga_director.tests.*',
            'ansible_collections.t_systems_mms.icinga_director.tests',
            'ansible_collections.t_systems_mms.icinga_director.docs.*',
            'ansible_collections.t_systems_mms.icinga_director.docs',
            'ansible_collections.theforeman.foreman.tests.*',
            'ansible_collections.theforeman.foreman.tests',
            'ansible_collections.theforeman.foreman.docs.*',
            'ansible_collections.theforeman.foreman.docs',
            'ansible_collections.vmware.vmware_rest.tests.*',
            'ansible_collections.vmware.vmware_rest.tests',
            'ansible_collections.vmware.vmware_rest.docs.*',
            'ansible_collections.vmware.vmware_rest.docs',
            'ansible_collections.vultr.cloud.tests.*',
            'ansible_collections.vultr.cloud.tests',
            'ansible_collections.vultr.cloud.docs.*',
            'ansible_collections.vultr.cloud.docs',
            'ansible_collections.vyos.vyos.tests.*',
            'ansible_collections.vyos.vyos.tests',
            'ansible_collections.vyos.vyos.docs.*',
            'ansible_collections.vyos.vyos.docs',
            'ansible_collections.wti.remote.tests.*',
            'ansible_collections.wti.remote.tests',
            'ansible_collections.wti.remote.docs.*',
            'ansible_collections.wti.remote.docs',
        ],
    ),
    package_dir={'': '.'},
    package_data={
        'ansible_collections.amazon.aws': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.ansible.netcommon': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'LICENSES/**/*', 'LICENSES/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.ansible.posix': [
            '*',
            'hacking/**/*', 'hacking/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.ansible.utils': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.ansible.windows': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.arista.eos': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.awx.awx': [
            '*',
            'test/**/*', 'test/**/.*',
            'images/**/*', 'images/**/.*',
            'meta/**/*', 'meta/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.azure.azcollection': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.check_point.mgmt': [
            '*',
            'roles/**/*', 'roles/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.chocolatey.chocolatey': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.cisco.aci': [
            '*',
            'roles/**/*', 'roles/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'playbooks/**/*', 'playbooks/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.cisco.asa': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.cisco.dnac': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'playbooks/**/*', 'playbooks/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.cisco.intersight': [
            '*',
            'misc/**/*', 'misc/**/.*',
            'roles/**/*', 'roles/**/.*',
            'meta/**/*', 'meta/**/.*',
            'playbooks/**/*', 'playbooks/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.cisco.ios': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.cisco.iosxr': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.cisco.ise': [
            '*',
            'roles/**/*', 'roles/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'playbooks/**/*', 'playbooks/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.cisco.meraki': [
            '*',
            'scripts/**/*', 'scripts/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.cisco.mso': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.cisco.nso': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.cisco.nxos': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.cisco.ucs': [
            '*',
            'misc/**/*', 'misc/**/.*',
            'roles/**/*', 'roles/**/.*',
            'meta/**/*', 'meta/**/.*',
            'playbooks/**/*', 'playbooks/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.cloud.common': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.cloudscale_ch.cloud': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.aws': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.azure': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
        ],
        'ansible_collections.community.ciscosmb': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.crypto': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'LICENSES/**/*', 'LICENSES/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.digitalocean': [
            '*',
            'scripts/**/*', 'scripts/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.dns': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'LICENSES/**/*', 'LICENSES/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.docker': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'LICENSES/**/*', 'LICENSES/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.fortios': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.general': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'LICENSES/**/*', 'LICENSES/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.google': [
            '*',
            'scripts/**/*', 'scripts/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.grafana': [
            '*',
            'hacking/**/*', 'hacking/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.hashi_vault': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'LICENSES/**/*', 'LICENSES/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.hrobot': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'LICENSES/**/*', 'LICENSES/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.libvirt': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.mongodb': [
            '*',
            'roles/**/*', 'roles/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.mysql': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.network': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.okd': [
            '*',
            'ci/**/*', 'ci/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
            'molecule/**/*', 'molecule/**/.*',
        ],
        'ansible_collections.community.postgresql': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.proxysql': [
            '*',
            'roles/**/*', 'roles/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.rabbitmq': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.routeros': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'LICENSES/**/*', 'LICENSES/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.sap': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.sap_libs': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.skydive': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.sops': [
            '*',
            'roles/**/*', 'roles/**/.*',
            'meta/**/*', 'meta/**/.*',
            'LICENSES/**/*', 'LICENSES/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'playbooks/**/*', 'playbooks/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.vmware': [
            '*',
            'scripts/**/*', 'scripts/**/.*',
            'tools/**/*', 'tools/**/.*',
            'meta/**/*', 'meta/**/.*',
            'LICENSES/**/*', 'LICENSES/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.windows': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.community.zabbix': [
            '*',
            'roles/**/*', 'roles/**/.*',
            'scripts/**/*', 'scripts/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
            'molecule/**/*', 'molecule/**/.*',
        ],
        'ansible_collections.containers.podman': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.cyberark.conjur': [
            '*',
            'roles/**/*', 'roles/**/.*',
            'ci/**/*', 'ci/**/.*',
            'meta/**/*', 'meta/**/.*',
            'examples/**/*', 'examples/**/.*',
            'dev/**/*', 'dev/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.cyberark.pas': [
            '*',
            'roles/**/*', 'roles/**/.*',
            'meta/**/*', 'meta/**/.*',
            'plugins/**/*', 'plugins/**/.*',
            'custom-cred-types/**/*', 'custom-cred-types/**/.*',
        ],
        'ansible_collections.dellemc.enterprise_sonic': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'playbooks/**/*', 'playbooks/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.dellemc.openmanage': [
            '*',
            'roles/**/*', 'roles/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'playbooks/**/*', 'playbooks/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.dellemc.powerflex': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.dellemc.unity': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.f5networks.f5_modules': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.fortinet.fortimanager': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.fortinet.fortios': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'examples/**/*', 'examples/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.frr.frr': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.gluster.gluster': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.google.cloud': [
            '*',
            'roles/**/*', 'roles/**/.*',
            'scripts/**/*', 'scripts/**/.*',
            'test-fixtures/**/*', 'test-fixtures/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
            'molecule/**/*', 'molecule/**/.*',
        ],
        'ansible_collections.grafana.grafana': [
            '*',
            'roles/**/*', 'roles/**/.*',
            'tools/**/*', 'tools/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'examples/**/*', 'examples/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.hetzner.hcloud': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.hpe.nimble': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.ibm.qradar': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.ibm.spectrum_virtualize': [
            '*',
            'roles/**/*', 'roles/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'playbooks/**/*', 'playbooks/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.infinidat.infinibox': [
            '*',
            'ibox_vars/**/*', 'ibox_vars/**/.*',
            'test-args/**/*', 'test-args/**/.*',
            'meta/**/*', 'meta/**/.*',
            'bin/**/*', 'bin/**/.*',
            'playbooks/**/*', 'playbooks/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.infoblox.nios_modules': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'playbooks/**/*', 'playbooks/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.inspur.ispim': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.inspur.sm': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'playbooks/**/*', 'playbooks/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.junipernetworks.junos': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.kubernetes.core': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.lowlydba.sqlserver': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.microsoft.ad': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.netapp.aws': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.netapp.azure': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.netapp.cloudmanager': [
            '*',
            'execution_environments/**/*', 'execution_environments/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.netapp.elementsw': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.netapp.ontap': [
            '*',
            'execution_environments/**/*', 'execution_environments/**/.*',
            'roles/**/*', 'roles/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'playbooks/**/*', 'playbooks/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.netapp.storagegrid': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.netapp.um_info': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.netapp_eseries.santricity': [
            '*',
            'roles/**/*', 'roles/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
            'vars/**/*', 'vars/**/.*',
        ],
        'ansible_collections.netbox.netbox': [
            '*',
            'hacking/**/*', 'hacking/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.ngine_io.cloudstack': [
            '*',
            'scripts/**/*', 'scripts/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.ngine_io.exoscale': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.ngine_io.vultr': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.openstack.cloud': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.openvswitch.openvswitch': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.ovirt.ovirt': [
            '*',
            'licenses/**/*', 'licenses/**/.*',
            'exported-artifacts/**/*', 'exported-artifacts/**/.*',
            'roles/**/*', 'roles/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'examples/**/*', 'examples/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.purestorage.flasharray': [
            '*',
            'roles/**/*', 'roles/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'playbooks/**/*', 'playbooks/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.purestorage.flashblade': [
            '*',
            'roles/**/*', 'roles/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'playbooks/**/*', 'playbooks/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.purestorage.fusion': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'playbooks/**/*', 'playbooks/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.sensu.sensu_go': [
            '*',
            'roles/**/*', 'roles/**/.*',
            'tools/**/*', 'tools/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'docker/**/*', 'docker/**/.*',
            'plugins/**/*', 'plugins/**/.*',
            'vagrant/**/*', 'vagrant/**/.*',
        ],
        'ansible_collections.servicenow.servicenow': [
            '*',
            'update_sets/**/*', 'update_sets/**/.*',
            'config/**/*', 'config/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.splunk.es': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.t_systems_mms.icinga_director': [
            '*',
            'roles/**/*', 'roles/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'examples/**/*', 'examples/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.theforeman.foreman': [
            '*',
            'roles/**/*', 'roles/**/.*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.vmware.vmware_rest': [
            '*',
            'config/**/*', 'config/**/.*',
            'meta/**/*', 'meta/**/.*',
            'manual/**/*', 'manual/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.vultr.cloud': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.vyos.vyos': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'changelogs/**/*', 'changelogs/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
        'ansible_collections.wti.remote': [
            '*',
            'meta/**/*', 'meta/**/.*',
            'playbooks/**/*', 'playbooks/**/.*',
            'plugins/**/*', 'plugins/**/.*',
        ],
    },
    install_requires=[
        'ansible-core ~= 2.15.0b2',
    ],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Console',
        'Framework :: Ansible',
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Natural Language :: English',
        'Operating System :: POSIX',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Topic :: System :: Installation/Setup',
        'Topic :: System :: Systems Administration',
        'Topic :: Utilities',
    ],
    data_files=[],
    entry_points={
        'console_scripts': [
            'ansible-community=ansible_collections.ansible_community:main'
        ]
    },
    # Installing as zip files would break due to references to __file__
    zip_safe=False
)